@@ -7,7 +7,6 @@ import numpy as np
 import onnxruntime
 from loguru import logger
 
-from .. import _contextlib
 from ._blob import Blob
 from ._generate import GenerateRequest
 from ._generate import GenerateResponse
@@ -35,18 +34,16 @@ class Model(abc.ABC):
                         providers = ["CUDAExecutionProvider", "CPUExecutionProvider"]
                     else:
                         providers = ["CPUExecutionProvider"]
-                # Suppress all the error messages from the missing providers.
-                with _contextlib.suppress():
-                    inference_session = onnxruntime.InferenceSession(
-                        blob.path, providers=providers
-                    )
+                inference_session = onnxruntime.InferenceSession(
+                    blob.path, providers=providers
+                )
             except Exception as e:
                 # Even though there is fallback in onnxruntime, it won't always work.
                 # e.g., CUDA is installed and CUDA_PATH is set, but CUDA_VISIBLE_DEVICES
                 # is empty. We fallback to cpu in such cases.
                 logger.error(
                     "Failed to create inference session with providers {providers!r}. "
-                    "Falling back to ['CPUExecutionProvider']",
+                    "Falling back to ['CPUExecutionProvider']: {e}",
                     providers=providers,
                     e=e,
                 )
